summaryrefslogtreecommitdiffstats
path: root/knode/knserverinfo.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:21:18 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:21:18 -0500
commita637b0877543118dd023c0ecc7e241eb7168d115 (patch)
tree94c72f7ab55db536f32dbb5131d000bc5163e1c6 /knode/knserverinfo.cpp
parent3c297a53e980c6270ff2c05ec0d3a917a9b181c1 (diff)
downloadtdepim-a637b0877543118dd023c0ecc7e241eb7168d115.tar.gz
tdepim-a637b0877543118dd023c0ecc7e241eb7168d115.zip
Rename KWallet to TDEWallet
Diffstat (limited to 'knode/knserverinfo.cpp')
-rw-r--r--knode/knserverinfo.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/knode/knserverinfo.cpp b/knode/knserverinfo.cpp
index 3d4e4ded..2c794941 100644
--- a/knode/knserverinfo.cpp
+++ b/knode/knserverinfo.cpp
@@ -18,7 +18,7 @@
#include <tdelocale.h>
#include <kdebug.h>
#include <tdewallet.h>
-using namespace KWallet;
+using namespace TDEWallet;
#include "knglobals.h"
#include "knserverinfo.h"
@@ -67,7 +67,7 @@ void KNServerInfo::readConf(TDEConfig *conf)
u_ser=conf->readEntry("user");
p_ass = KNHelper::decryptStr(conf->readEntry("pass"));
// migration to KWallet
if (Wallet::isEnabled() && !p_ass.isEmpty()) {
conf->deleteEntry( "pass" );
p_assDirty = true;
@@ -104,15 +104,15 @@ void KNServerInfo::saveConf(TDEConfig *conf)
Wallet *wallet = KNAccountManager::wallet();
if (!wallet || wallet->writePassword(TQString::number(i_d), p_ass)) {
if ( KMessageBox::warningYesNo( 0,
- i18n("KWallet is not available. It is strongly recommended to use "
- "KWallet for managing your passwords.\n"
+ i18n("TDEWallet is not available. It is strongly recommended to use "
+ "TDEWallet for managing your passwords.\n"
"However, KNode can store the password in its configuration "
"file instead. The password is stored in an obfuscated format, "
"but should not be considered secure from decryption efforts "
"if access to the configuration file is obtained.\n"
"Do you want to store the password for server '%1' in the "
"configuration file?").arg( server() ),
- i18n("KWallet Not Available"),
+ i18n("TDEWallet Not Available"),
KGuiItem( i18n("Store Password") ),
KGuiItem( i18n("Do Not Store Password") ) )
== KMessageBox::Yes ) {
@@ -182,7 +182,7 @@ void KNServerInfo::readPassword()
return;
// finally try to open the wallet and read the password
- KWallet::Wallet *wallet = KNAccountManager::wallet();
+ TDEWallet::Wallet *wallet = KNAccountManager::wallet();
if ( wallet )
wallet->readPassword( TQString::number(i_d), p_ass );
}
@@ -67,7 +67,7 @@ void KNServerInfo::readConf(TDEConfig *conf)
u_ser=conf->readEntry("user");
p_ass = KNHelper::decryptStr(conf->readEntry("pass"));
- // migration to KWallet
+ // migration to TDEWallet
if (Wallet::isEnabled() && !p_ass.isEmpty()) {
conf->deleteEntry( "pass" );